function bias = bootstrap_stambaugh(r,x,params)
% function bias = bootstrap_stambaugh(r,x,params)
%
% r is the index return, x is the univariate predictor, both observed at
% the same time
% 
% Finds magnitude of Stambaugh (1999) bias using the simulation approach
% from Goyal and Welch (2008)
% 

T = length(r); 
K = size(x,2)+1; 

% Estimate parameter vector: [ mur; mux; rhox; ]
mu_r = mean(r); 
data_eps = r(2:end) - mu_r;

coeff_x = [ones(T-1,1) x(1:end-1,1)] \ x(2:end,1); 
mu_x = coeff_x(1,1) / (1 - coeff_x(2,1) ); 
rho_x = coeff_x(2,1); 

% delta is innovation in x
data_delta = x(2:end,1) - [ones(T-1,1) x(1:end-1,1)]*coeff_x; 

% we'll jointly resample these innovations to capture their correlation
data_errorvec = [ data_eps data_delta  ] ; 

sim_ols_coeff = zeros(params.nsim,2); 

% Theta is a vector contianing r and x
data_theta = [ r x ];

fprintf('        '); 
for i = 1:params.nsim
    % Initial theta drawn randomly from the data
    init_theta = data_theta(randi(T),:);
    
    % Redraw errors
    samplei = randsample(T-1,T-1,true); 
    sim_errorvec = data_errorvec(samplei,:); 
    
    % this is a computational trick to make the simulations go faster by
    % avoiding a second for loop within each sim
    csxerrors = cumsum(sim_errorvec(:,2)./(rho_x.^(-T/2:T/2-2)')); 
    simx = [init_theta(2); mu_x + (init_theta(2)-mu_x)*rho_x.^((1:T-1)') + ...
        csxerrors.*rho_x.^((-T/2:T/2-2)')]; 
    
    % sometimes the trick fails because we run out of digits matlab can
    % store, so we need that second for loop
    if( sum(isinf(simx) > 0 ) )
        simx(1,1) = init_theta(2); 
        for j = 2:T
            simx(j,1) = rho_x*simx(j-1,1) + sim_errorvec(j-1,1); 
        end
    end
    
    simr = zeros(T,1); simr(1,1) = init_theta(1); 
    simr(2:end,1) = mu_r + sim_errorvec(:,1);
    
    % Now Do regressions with homoskedastic simr
    LHS = params.lhsmultiplier*simr(params.nfutperiods+1:end,1); 
    RHS = makerhs(simx,params.nfutperiods);
    
    % ols
    sim_ols_coeff(i,:) = (RHS \ LHS)';

    if(mod(i,500) == 0 && floor(100*i/params.nsim) < 100)
        fprintf(1,'\b\b\b\b\b\b\b\b%2d%% done',floor(100*i/params.nsim));
    end
end
fprintf(1,'\b\b\b\b\b\b\b\b%2d%% done',floor(100*i/params.nsim));
fprintf('\n');

% bias is simply the mean coefficient you get under the null in this type
% of simulation
bias = mean(sim_ols_coeff(:,2:end),1);

end

function rhs = makerhs(x,nfutperiods)
    rollx = conv(x,ones(1,nfutperiods),'valid'); 
    rollx = rollx(~isnan(rollx),1); 
    rollx = rollx*var(x)/var(rollx);

    rhs = [ones(length(rollx)-1,1) rollx(1:end-1,1)]; 
end