%% This is the main script that creates all the Tables and Figures for
% "A Fresh Look at Return Predictability Using Weighted Least Squares" (2018) by 
% Travis L. Johnson
% http://travislakejohnson.com

clear variables; close all; clc; 

% TO USE THIS, YOU NEED TO CHOOSE FOLDER FOR ALL THE OUTPUT
base_folder = 'C:\Dropbox\GLS\For website\Test output\'; 

% AND CHANGE THIS TO THE FOLDER ALL THE CODE IS IN
code_folder = 'C:\Dropbox\GLS\For website\Code\';

% AND CHANGE THIS TO THE FOLDER Johnson2018_data_merged IS IN
data_folder = 'C:\Dropbox\GLS\For website\Data\';

% ALSO NEED TO CHOOSE NUMBER OF SIMULATIONS TO RUN
% global_num_sims = 1000; % for testing/speed, takes around 30 mins
global_num_sims = 100000; % for actual results, takes around 12 hours

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Preliminaries

% load all the data. See paper for details on variable construction and
% data sources
load([data_folder 'Johnson2018_data_merged.mat']); 

% change directory the folder with the code
cd(code_folder); 

% add export_fig to path
addpath([code_folder 'export_fig\']); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Table 1: predicting realized variance

disp('Making Table 1: Effectiveness of Ex-ante Variance Proxies'); 

% LHS vars for Table 1
LHS_full_m = fullsample_m.rv_1; 
LHS_vix_d = vixsample_d.futrv_1;

% Panel A:
numrows = 11; 
T = height(fullsample_m); 
Table1a = [ make_var_prediction_col(LHS_full_m,[ ones(T,1) fullsample_m.rv_0 ],[1; 3],numrows) ... 
    make_var_prediction_col(LHS_full_m,[ ones(T,1) fullsample_m.rv_m2_0 ],[1; 5],numrows) ...
    make_var_prediction_col(LHS_full_m,[ ones(T,1) fullsample_m.rv_m5_0 ],[1; 7],numrows) ... 
    make_var_prediction_col(LHS_full_m,[ ones(T,1) fullsample_m.rv_m11_0 ],[1; 9],numrows) ...
    make_var_prediction_col(LHS_full_m,[ ones(T,1) fullsample_m.rv_0 fullsample_m.rv_m2_0 ...
        fullsample_m.rv_m5_0 fullsample_m.rv_m11_0],[1; 3;5;7;9],numrows) ...
    make_var_prediction_col(LHS_full_m,[ ones(T,1) fullsample_m.rv_0 fullsample_m.rv_m11_0],[1; 3;9],numrows) ...
     ];
    
% output to csv
output_params.numdigits = 3;
output_params.secondrow = 'stderrors'; 
writetable_tj([ base_folder 'Table1a.csv' ],Table1a,(1:2:9)',(2:2:10)',output_params);

% Panel B:
numrows = 13; 
T = height(vixsample_d); 

Table1b = [ make_var_prediction_col(LHS_vix_d,[ ones(T,1) vixsample_d.rv_m20_0 vixsample_d.rv_m251_0 ],[1; 3; 5],numrows) ... 
    make_var_prediction_col(LHS_vix_d,[ ones(T,1) vixsample_d.futrv_0 ], [1;7],numrows) ...
    make_var_prediction_col(LHS_vix_d,[ ones(T,1) vixsample_d.futrv_m20_0 ],[1; 9],numrows) ...
    make_var_prediction_col(LHS_vix_d,[ ones(T,1) (1/252)*vixsample_d.vix.^2],[1; 11],numrows) ... 
    make_var_prediction_col(LHS_vix_d,[ ones(T,1) vixsample_d.rv_m20_0 vixsample_d.rv_m251_0 ...
        vixsample_d.futrv_0 vixsample_d.futrv_m20_0 (1/252)*vixsample_d.vix.^2],(1:2:11)',numrows) ...
    make_var_prediction_col(LHS_vix_d,[ vixsample_d.futrv_0 ...
        (1/252)*vixsample_d.vix.^2],[7; 11],numrows) ];

writetable_tj([ base_folder 'Table1b.csv' ],Table1b,(1:2:11)',(2:2:12)',output_params);

% Correlation matrix (untabulated)

% this will be a matrix with 3 columns containing the 3 diff \hat{sigsq}
eom_sigsq = zeros(height(vixsample_m),3); 
for m = 1:length(eom_sigsq)
    eom_sigsq(m,1) = vixsample_m.sigsq_rv(m); 
    d_selector = vixsample_d.date == vixsample_m.date(m);
    eom_sigsq(m,2) = vixsample_d.sigsq_rv(d_selector); 
    eom_sigsq(m,3) = vixsample_d.sigsq_both(d_selector); 
end

corr_mat_sigsq = corr(eom_sigsq); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Table 2: traditional predictors

disp('Making Table 2: In-Sample Return Predictability'); 
disp('    And part of Online Appendix Table 5: Hodrick (1992) vs Newey West (1987)'); 

% gwmerged has the Goyal Welch predictors and the monthly var stats
gwmerged = innerjoin(predictors,fullsample_m,'key','month'); 
gwmerged = outerjoin(gwmerged,payoutyield,'keys','month','RightVariables','lpayoutyield');
gwmerged = outerjoin(gwmerged,cay_m,'keys','month','RightVariables',{'cay','caya'});
gwmerged = gwmerged(~isnan(gwmerged.month),:); 
gwmerged.gwmkt = log(1+gwmerged.mktrf); 

% params must contain lhsmultiplier, nfutperiods, nsim, nlags, and
% nfutperiods
clear params; 
params.nsim = global_num_sims; 
params.lhsmultiplier = 1; 
params.nlags = 12; % for Newey-West

% First, do the next-1 version
params.nfutperiods = 1; % h=1 in Panel A
[ Table2_next1, Table2_next1_summary ] = make_gw_is_table(gwmerged,params); 

% Now, do the next-12
params.nfutperiods = 12; % h=12 in Panel B
[ Table2_next12, Table2_next12_summary ] = make_gw_is_table(gwmerged,params); 

% reshape them
Table2_next1 = [ Table2_next1(:,2:12); NaN(1,11); Table2_next1(:,14:24); ...
    NaN(1,11); Table2_next1(:,26:36); NaN(1,11); Table2_next1(:,38:48) ]; 

Table2_next12 = [ Table2_next12(:,2:12); NaN(1,11); Table2_next12(:,14:24); ...
    NaN(1,11); Table2_next12(:,26:36); NaN(1,11); Table2_next12(:,38:48) ]; 

% write as csv files
output_params.numdigits = 3; 
output_params.secondrow = 'pvals'; 
writetable_tj([ base_folder 'Table2a.csv'],Table2_next1,[1 8 15 22],[6 13 20 27],output_params);
writetable_tj([ base_folder 'Table2b.csv'],Table2_next12,[1 8 15 22],[6 13 20 27],output_params);
csvwrite( [ base_folder 'Table2a_summary.csv' ],Table2_next1_summary );
csvwrite( [ base_folder 'Table2b_summary.csv' ],Table2_next12_summary );

% make oapptab5 column for dy
% this table compares the hodrick (1992) mapping I use for ovelrappoing
% regressions ot the more-typical newey-west approach
hodvsnw_in.x = gwmerged.dp/100; 
hodvsnw_in.r = gwmerged.gwmkt;
hodvsnw_in.hod_sigsq = gwmerged.sigsq_rv; 
hodvsnw_in.rv = gwmerged.rv_0; 
hodvsnw_in.var_predictors = [ gwmerged.rv_m11_0 gwmerged.rv_0 ]; 

hodvsnw_params.nsim = global_num_sims; 
hodvsnw_params.lhsmultiplier = 1; 
hodvsnw_params.nfutperiods = 12; 
hodvsnw_params.adjuststambaugh = true; 
hodvsnw_params.hod_nlags = 12; 
hodvsnw_params.nw_nlags = 18; 

OAppTable5_dp = make_hodvsnw_table(hodvsnw_in,hodvsnw_params); 

% for tms
hodvsnw_in.x = gwmerged.tms; 

OAppTable5_tms = make_hodvsnw_table(hodvsnw_in,hodvsnw_params); 

% and for cay
selector = ~isnan(gwmerged.cay); 

hodvsnw_in.x = gwmerged.cay(selector,1); 
hodvsnw_in.r = gwmerged.gwmkt(selector,1);
hodvsnw_in.hod_sigsq = gwmerged.sigsq_rv(selector,1); 
hodvsnw_in.rv = gwmerged.rv_0(selector,1); 
hodvsnw_in.var_predictors = [ gwmerged.rv_m11_0(selector,1) gwmerged.rv_0(selector,1) ]; 

OAppTable5_cay = make_hodvsnw_table(hodvsnw_in,hodvsnw_params); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUT OF SAMPLE GOYAL WELCH

 % (Table 3, Figure 2, Online Appendix Figure 1, Online Appendix Table 1)

disp('Making Table 3: Out-of-Sample Return Predictability'); 
disp('    And Figure 2: Illustration of Out-of-Sample Performance Improvement'); 
disp('    And Online Appendix Figure 1: Illustrations of Out-of-Sample Performance Improvement'); 
disp('    And Online Appendix Table 1: Out-of-Sample Certainty Equivalents'); 
 
% need to add variables for use in rolling OOS first-stage
gwmerged.sigsq = [ gwmerged.rv_0 gwmerged.rv_m11_0 ];
 
% params must contain nfutperiods, nsim, logret, ntraining
clear params; 

params.ntraining = 12*20;
params.base_folder = base_folder;

% Correct signs for Campbell Thompson approach
params.ct_signs = [ 1 1 1 1 1 -1 -1 1 1 1 -1 1 1 -1 1 1 ]'; 

params.nsim = global_num_sims;

params.nfutperiods = 1; % for Panel A 
params.nsim = global_num_sims / 2;
[ Table3_next1, Table3_next1_summary, OAppTable1_next1, OAppTable1_next1_summary ] = ...
    make_gw_oos_table( gwmerged, params ); 

params.nfutperiods = 12; % for Panel B
params.nsim = global_num_sims / 2;
[ Table3_next12, Table3_next12_summary, OAppTable1_next12, OAppTable1_next12_summary ] = ...
    make_gw_oos_table( gwmerged, params );


% reshape them
Table3_next1_shaped = [ Table3_next1(:,1:12); NaN(1,12); Table3_next1(:,13:24); ...
    NaN(1,12); Table3_next1(:,25:36); NaN(1,12); Table3_next1(:,37:48) ]; 

Table3_next12_shaped = [ Table3_next12(:,1:12); NaN(1,12); Table3_next12(:,13:24); ...
    NaN(1,12); Table3_next12(:,25:36); NaN(1,12); Table3_next12(:,37:48) ]; 

OAppTable1_next1 = [ OAppTable1_next1(:,2:12); NaN(1,11); OAppTable1_next1(:,14:24); ...
    NaN(1,11); OAppTable1_next1(:,26:36); NaN(1,11); OAppTable1_next1(:,38:48) ]; 

OAppTable1_next12 = [ OAppTable1_next12(:,2:12); NaN(1,11); OAppTable1_next12(:,14:24); ...
    NaN(1,11); OAppTable1_next12(:,26:36); NaN(1,11); OAppTable1_next12(:,38:48) ]; 

%write as csv files
output_params.numdigits = 2; 
output_params.secondrow = 'pvals'; 
output_params.as_percent = true; 

% csvwrite( [ base_folder 'Table3a.csv' ],Table3_next1 );
writetable_tj([ base_folder 'Table3a.csv' ],Table3_next1_shaped,[ 1:2:5 8:2:12 15:2:19 22:2:26 ], ...
    [ 2:2:6 9:2:13 16:2:20 23:2:27 ],output_params)
csvwrite( [ base_folder 'Table3a_summary.csv' ],Table3_next1_summary );
writetable_tj([ base_folder 'Table3b.csv' ],Table3_next12_shaped,[ 1:2:5 8:2:12 15:2:19 22:2:26 ], ...
    [ 2:2:6 9:2:13 16:2:20 23:2:27 ],output_params)
csvwrite( [ base_folder 'Table3b_summary.csv' ],Table3_next12_summary );
csvwrite( [ base_folder 'OAppTable1a.csv' ],OAppTable1_next1 );
csvwrite( [ base_folder 'OAppTable1a_summary.csv' ],OAppTable1_next1_summary );
csvwrite( [ base_folder 'OAppTable1b.csv' ],OAppTable1_next12 );
csvwrite( [ base_folder 'OAppTable1b_summary.csv' ],OAppTable1_next12_summary );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Main VRP analysis (Table 4, OAppTable 2)

disp('Making Table 4: Predicting Returns Using the Variance Risk Premium');
disp('     And Online Appendix Table 2:  Predicting Returns Using Alternative VRP');

clear params;
params.nsim = global_num_sims;
params.allnfutperiods = [21; 63]; % number of days ahead to forecast
params.lhsmultipliers = 100*[12 4]; % Scale up returns

% for daily, use 21 lags for NW
params.nlags = 21; 

% These are x for Table 5, attempting to replicate original papers
dy_x = vixsample_d.vrp_dy; 
btz_x = vixsample_d.vrp_btz;  
Table4a = make_vrp_table(vixsample_d, dy_x, params); 
Table4b = make_vrp_table(vixsample_d, btz_x, params); 

% These are first alternative x for appendix
btz_x = make_quantile(vixsample_d.vrp_btz,10);
dy_x = make_quantile(vixsample_d.vrp_dy,10);
OAppTable2a_1 = make_vrp_table(vixsample_d, dy_x, params); 
OAppTable2b_1 = make_vrp_table(vixsample_d, btz_x, params); 
 
% These are second alternative x for appendix
btz_x = max(vixsample_d.vrp_btz,0); 
dy_x = max(vixsample_d.vrp_dy,0); 
OAppTable2a_2 = make_vrp_table(vixsample_d, dy_x, params); 
OAppTable2b_2 = make_vrp_table(vixsample_d, btz_x, params); 

% concatenate OApp tables
OAppTable2a = [ OAppTable2a_1; NaN(1,7); OAppTable2a_2 ]; 
OAppTable2b = [ OAppTable2b_1; NaN(1,7); OAppTable2b_2 ]; 

% write to csv files 
output_params.numdigits = 3; 
output_params.secondrow = 'pvals'; 

writetable_tj([ base_folder 'Table4a.csv'],Table4a,1,6,output_params);
writetable_tj([ base_folder 'Table4b.csv'],Table4b,1,6,output_params);
writetable_tj([ base_folder 'OAppTable2a.csv'],OAppTable2a,[1 8],[6 13],output_params);
writetable_tj([ base_folder 'OAppTable2b.csv'],OAppTable2b,[1 8],[6 13],output_params);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% VRP Replication/alternative procedures (Table 5)

disp('Making Table 5: Predicting Returns Using the Variance Risk Premium: Alternative Procedures');
disp('     And finishing Online Appendix 5: Methods for Addressing Overlapping Observations');  

clear params;
params.nsim = global_num_sims;

% dy version for panel a
Table5a = make_dy_alt_table(vixsample_d,vixsample_m,vixsample_m_off,params); 

% btz version for panel b

% merged in data from Hao Zhou's website
vrpmerged_m = innerjoin(vixsample_m,VRPtable,'keys','month'); 
Table5b = make_btz_alt_table(vixsample_d,vrpmerged_m,vixsample_m_off,params); 

% write to csv
output_params.numdigits = 3; 
output_params.secondrow = 'pvals'; 

writetable_tj([ base_folder 'Table5a.csv'],Table5a,[1 8],[6 13],output_params);
writetable_tj([ base_folder 'Table5b.csv'],Table5b,[1 8],[6 13],output_params);

% make hodrick vs nw table for VRP
hodvsnw_in.x = vixsample_d.vrp_btz; 
hodvsnw_in.r = log(1+vixsample_d.mktrf);
hodvsnw_in.hod_sigsq = vixsample_d.sigsq_both; 
hodvsnw_in.rv = vixsample_d.futrv_0; 
hodvsnw_in.var_predictors = [ vixsample_d.vix.^2 vixsample_d.futrv_0 ]; 

hodvsnw_params.nsim = global_num_sims; 
hodvsnw_params.lhsmultiplier = 400; 
hodvsnw_params.nfutperiods = 63; 
hodvsnw_params.adjuststambaugh = true; 
hodvsnw_params.hod_nlags = 21; 
hodvsnw_params.nw_nlags = 96; 

OAppTable5_vrp = make_hodvsnw_table(hodvsnw_in,hodvsnw_params); 

% output full OAppTable5_vrp
OAppTable5 = [ OAppTable5_dp NaN(6,1) OAppTable5_tms ; ...
    NaN(1,11); ...
    OAppTable5_cay NaN(6,1) OAppTable5_vrp ]; 

% write to csv
output_params.numdigits = 3; 
output_params.secondrow = 'pvals'; 

writetable_tj([ base_folder 'OAppTable5.csv'],OAppTable5,[1;8],[6;13],output_params); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Table 6: novymarx

disp('Making Table 6: Predicting Returns Using Politics, the Weather, and the Stars');

% Merge in novy-marx data
novymarx_plus = innerjoin(novymarx,fullsample_m,'keys','month'); 

% call function that makes table
clear params; 
params.nsim = global_num_sims*2;
params.nlags = 12; % for newey west
[ Table6, Table6_summary ] = make_nm_table(novymarx_plus,params); 

% write to csv
output_params.numdigits = 3; 
output_params.secondrow = 'pvals'; 

writetable_tj([ base_folder 'Table6.csv' ],Table6,1:3:size(Table6,1),3:3:size(Table6,1),output_params); 
writetable_tj([ base_folder 'Table6_summary.csv' ],Table6_summary,[1 3],[2 4],output_params); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Table 7: Presidential Puzzle

disp('Making Table 7: Presidential Puzzle');

% merge in presidential_puzzle data, set our return metric
pres_merged = innerjoin(presidential_puzzle,fullsample_m,'keys','month');
pres_merged.ret = log(1+pres_merged.mktrf);

% Panels A and B

% T = number of observations
T = height(pres_merged); 

% SIMULATIONS
params.nsim = global_num_sims; 
% params.rho_er = 0.5^(1/72); % make half-life of four years for ferson business
params.rho_er = autocorr(pres_merged.dem); 
params.sig_er = mean(pres_merged.ret) / abs(norminv(0.10)); % make negative ers happen 10% of time

% Ferson et all, homosked
% params.use_ferson = true;
% params.rho_er = 0.5^(1/48); % make half-life of four years
% params.sig_er = mean(pres_data.ret(ret_inds,1))/ abs(norminv(0.5)); % make negative ers happen 19% of time
% params.homosked = true;
% simr_fss_ho = 1200*sim_returns(pres_data.ret(ret_inds), truevar, params); 

% No Ferson, heterosked
params.use_ferson = false;
params.homosked = false;
simr.he = 1200*sim_returns(pres_merged.ret, pres_merged.rv_0, params); 

% Ferson et al, heterosked
params.use_ferson = true;
params.homosked = false;
simr.fss_he = 1200*sim_returns(pres_merged.ret, pres_merged.rv_0, params); 

% Column 1: full sample
[ Table7a_full_ols, Table7a_full_wls ] = make_pres_col(pres_merged,simr,true(T,1)); 

% Column 2: through 1971
[ Table7a_firsthalf_ols, Table7a_firsthalf_wls ] = make_pres_col(pres_merged,simr,pres_merged.month <= 197112); 

% Column 3: post 1971
[ Table7a_secondhalf_ols, Table7a_secondhalf_wls ] = make_pres_col(pres_merged,simr,pres_merged.month >= 197201); 

% Column 4: exclude post-crash periods: 192911-193411 & 200811-200912
post_crash = ( pres_merged.month >= 192910 & pres_merged.month <= 193410 ) | ( pres_merged.month >= 200810 & pres_merged.month <= 200910 ); 
[ Table7a_nopostcrash_ols, Table7a_nopostcrash_wls ] = make_pres_col(pres_merged,simr,~post_crash); 

Table7a = [ Table7a_full_ols Table7a_full_wls NaN(7,1) ...
    Table7a_firsthalf_ols Table7a_firsthalf_wls NaN(7,1) ...
    Table7a_secondhalf_ols Table7a_secondhalf_wls NaN(7,1) ...
    Table7a_nopostcrash_ols Table7a_nopostcrash_wls  ];

% write to csv files 
output_params.numdigits = 3; 
output_params.secondrow = 'pvals'; 
writetable_tj([ base_folder 'Table7a.csv'],Table7a,4,6,output_params);

% Panel B: subsamples by volatility

[ Table7b_top1_ols, Table7b_top1_wls ] = make_pres_col(pres_merged,simr,pres_merged.sigsq_rv >= quantile(pres_merged.sigsq_rv,0.99)); 
[ Table7b_top10_ols, Table7b_top10_wls ] = make_pres_col(pres_merged,simr,pres_merged.sigsq_rv >= quantile(pres_merged.sigsq_rv,0.90)); 
[ Table7b_top20_ols, Table7b_top20_wls ] = make_pres_col(pres_merged,simr,pres_merged.sigsq_rv >= quantile(pres_merged.sigsq_rv,0.80)); 
[ Table7b_bottom80_ols, Table7b_bottom80_wls ] = make_pres_col(pres_merged,simr,pres_merged.sigsq_rv < quantile(pres_merged.sigsq_rv,0.80)); 


Table7b = [ Table7b_top1_ols Table7b_top1_wls NaN(7,1) ...
    Table7b_top10_ols Table7b_top10_wls NaN(7,1) ...
    Table7b_top20_ols Table7b_top20_wls NaN(7,1) ...
    Table7b_bottom80_ols Table7b_bottom80_wls];
   
output_params.numdigits = 3; 
output_params.secondrow = 'pvals'; 
writetable_tj([ base_folder 'Table7b.csv'],Table7b,4,6,output_params);

% Panel C: top 1% table
top1_sigsq_inds = find(pres_merged.sigsq_rv >= quantile(pres_merged.sigsq_rv,0.99)); 
top1_ret_inds = top1_sigsq_inds+1; 

Table7c = NaN(length(top1_sigsq_inds)+2,5); 

for i = 1:length(top1_sigsq_inds)
    Table7c(i,1) = pres_merged.month(top1_ret_inds(i)); 
    Table7c(i,2) = pres_merged.dem(top1_ret_inds(i)); 
    Table7c(i,3) = sqrt(pres_merged.sigsq_rv(top1_sigsq_inds(i))); 
    Table7c(i,4) = log(1+pres_merged.mktrf(top1_ret_inds(i))); 
    Table7c(i,5) = 12*log(1+pres_merged.mktrf(top1_ret_inds(i))); 
end

Table7c(end-1,4) = mean(Table7c( Table7c(:,2) == 1,4)); 
Table7c(end,4) = mean(Table7c( Table7c(:,2) == 0,4)); 
Table7c(end-1,5) = mean(Table7c( Table7c(:,2) == 1,5)); 
Table7c(end,5) = mean(Table7c( Table7c(:,2) == 0,5)); 

output_params.numdigits = 5; 

writetable_tj([ base_folder 'Table7c.csv'],Table7c,[],[],output_params); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Appendix Table 1: Simulations

disp('Making Appendix Table 1: Size, Power, and Data Mining in Simulations'); 
disp('And Online Appendix Table 5: Size, Power, and Data Mining in Alternative Simulations');

% DP PANELS:
% gwmerged has the Goyal Welch predictors and the monthly var stats
gwmerged = innerjoin(predictors,fullsample_m,'key','month'); 

% Now setup to "input table" required for make_sim_table

% Must have an x variable
dptablein = table(gwmerged.dp,'VariableNames',{'x'}); 
% sigma
dptablein.predvar = gwmerged.sigsq_rv; 
% realvar for rsq figure
dptablein.realvar = gwmerged.rv_0; 
% and the returns
dptablein.r = log(1+gwmerged.mktrf);
% finally, instruments to use for OOS 
dptablein.sigsq = [ gwmerged.rv_0 gwmerged.rv_m11_0 ];

% PANELS A, and C: no predictability null

% Parameters for the simulations under no predictability null
params.do_oos = true; 

params.truebeta = 0; 
params.critpvalues = [ 0.10 0.05 0.01 ]; 
params.critbeta_ols = 10*ones(1,3); % don't use crit values in first stage
params.critbeta_wls = 10*ones(1,3); % don't use crit values in first stage
params.critoosrsq_ols = 10*ones(1,3); 
params.critoosrsq_wls = 10*ones(1,3); 
params.lhsmultiplier = 100; 
params.nfutperiods = 1; 
params.nlags = 12; % use 12 lags for NW in div yield sims

% oos stuff
params.ntraining = 20*12; 
params.ct_sign = 1; 

% Now make the table for dp with 0 predictability null
params.nsim = global_num_sims*2; % double because we also need to condition on OLS/WLS being siig 
params.sim_x = false; 
[ outpanels_dp, critvalues ] = make_sim_table(dptablein,params);

params.sim_x = true; 
[ outpanels_dp_simx, critvalues_simx ] = make_sim_table(dptablein,params);

% Partition into panels
AppTable_dp_A = outpanels_dp.PanelA; 
AppTable_dp_C = outpanels_dp.PanelC; 
OAppTable_dp_A = outpanels_dp_simx.PanelA; 
OAppTable_dp_C = outpanels_dp_simx.PanelC; 

% PANEL B
% Tweak params so we are under the beta = 1 (AFTER being multiplied by LHS multiplier) null
% with critical values based on the 0 pred null
params.truebeta = 1/params.lhsmultiplier; 

% Now make the table for dp with 1 predictability null
params.nsim = global_num_sims; 

params.sim_x = false; 
params.critbeta_ols = critvalues.critbeta_ols; % get crit betas from null simulations
params.critbeta_wls = critvalues.critbeta_wls; 
params.critoosrsq_ols = critvalues.critoosrsq_ols;
params.critoosrsq_wls = critvalues.critoosrsq_wls;
outpanels_dp_pred = make_sim_table(dptablein,params); 

params.sim_x = true; 
params.critbeta_ols = critvalues_simx.critbeta_ols; % get crit betas from null simulations
params.critbeta_wls = critvalues_simx.critbeta_wls; 
params.critoosrsq_ols = critvalues_simx.critoosrsq_ols;
params.critoosrsq_wls = critvalues_simx.critoosrsq_wls;
outpanels_dp_pred_simx = make_sim_table(dptablein,params); 

% grab the right panel
AppTable_dp_B = outpanels_dp_pred.PanelB; 
OAppTable_dp_B = outpanels_dp_pred_simx.PanelB; 

% VRP PANELS:

% daily
% Redo x so we are estimating the t+1,t+nfutperiods overlapping
% predicability
x = vixsample_d.vrp_dy; 
params.varname = 'vrp'; 

% don't do oos for vrp panels
params.do_oos = false; 

% x:
vrptablein = table(x,'VariableNames',{'x'}); 
% sigma:
vrptablein.predvar = vixsample_d.sigsq_both; 
% realvar for rsq figure
vrptablein.realvar = vixsample_d.futrv_0; 
% returns:
vrptablein.r = log(1+vixsample_d.mktrf); 

% PANELS A and C: no predictability null
% Modify params to 0 predictability null
params.truebeta = 0; 
params.critpvalues = [ 0.10 0.05 0.01 ]; 
params.critbeta_ols = 10*ones(1,3); % don't use crit values in first stage
params.critbeta_wls = 10*ones(1,3); % don't use crit values in first stage
params.critoosrsq_ols = 10*ones(1,3); 
params.critoosrsq_wls = 10*ones(1,3); 
params.lhsmultiplier = 1200; 
params.nfutperiods = 21; 
params.nlags = 21; %use 21 lags for NW in vrp sims

% Make table for vrp with 0 predictability null
params.nsim = global_num_sims*2; % double because we also need to condition on OLS/WLS being siig 
params.sim_x = false; 
[ outpanels_vrp, critvalues ] = make_sim_table(vrptablein,params);

params.sim_x = true; 
[ outpanels_vrp_simx, critvalues_simx ] = make_sim_table(vrptablein,params);

% Partition into panels
AppTable_vrpd_A = outpanels_vrp.PanelA; 
AppTable_vrpd_C = outpanels_vrp.PanelC; 
OAppTable_vrpd_A = outpanels_vrp_simx.PanelA;
OAppTable_vrpd_C = outpanels_vrp_simx.PanelC; 

% PANEL B
% Switch to beta = 1 null
params.truebeta = 0.4/params.lhsmultiplier; 

% Now make the table for dp with 1 predictability null
params.nsim = global_num_sims; 

params.sim_x = false;
params.critbeta_ols = critvalues.critbeta_ols; % get crit betas from null simulations
params.critbeta_wls = critvalues.critbeta_wls; 
params.critoosrsq_ols = critvalues.critoosrsq_ols;
params.critoosrsq_wls = critvalues.critoosrsq_wls;
outpanels_vrp_pred = make_sim_table(vrptablein,params); 

params.sim_x = true;
params.critbeta_ols = critvalues_simx.critbeta_ols; % get crit betas from null simulations
params.critbeta_wls = critvalues_simx.critbeta_wls; 
params.critoosrsq_ols = critvalues_simx.critoosrsq_ols;
params.critoosrsq_wls = critvalues_simx.critoosrsq_wls;
outpanels_vrp_pred_simx = make_sim_table(vrptablein,params); 
% 
AppTable_vrpd_B = outpanels_vrp_pred.PanelB;
OAppTable_vrpd_B = outpanels_vrp_pred_simx.PanelB;

% output as csv files
AppTable1a = [ AppTable_dp_A NaN(size(AppTable_dp_A,1),1) AppTable_vrpd_A ]; 
AppTable1b = [ AppTable_dp_B NaN(size(AppTable_dp_B,1),1) AppTable_vrpd_B ];  
AppTable1c = [ AppTable_dp_C NaN(size(AppTable_dp_C,1),1) AppTable_vrpd_C ];  

OAppTable5a = [ OAppTable_dp_A NaN(size(OAppTable_dp_A,1),1) OAppTable_vrpd_A ]; 
OAppTable5b = [ OAppTable_dp_B NaN(size(OAppTable_dp_B,1),1) OAppTable_vrpd_B ];  
OAppTable5c = [ OAppTable_dp_C NaN(size(OAppTable_dp_C,1),1) OAppTable_vrpd_C ];  

csvwrite( [ base_folder 'AppTable1a.csv' ],AppTable1a); 
csvwrite( [ base_folder 'AppTable1b.csv' ],AppTable1b); 
csvwrite( [ base_folder 'AppTable1c.csv' ],AppTable1c); 

csvwrite( [ base_folder 'OAppTable1a.csv' ],OAppTable5a); 
csvwrite( [ base_folder 'OAppTable1b.csv' ],OAppTable5b); 
csvwrite( [ base_folder 'OAppTable1c.csv' ],OAppTable5c); 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make Figure 1: sigsq plots

disp('Making Figure 1: Conditional Variance Measures');

% Start with sigsq_rv in full sample
close all;

pos = [100 100 700 300] ;

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1, ...
    'XTickLabel',num2str(1930:10:2010), ...
    'XTick',datenum(1930:10:2010,12,31), ...
    'FontName','CMU Serif'); 

box(axes1,'on');
hold(axes1,'on');

% plot sigsq_rv
plot(tdatetomatlab(fullsample_m.date),100*sqrt(12*fullsample_m.sigsq_rv),'Color',[ 0 0 0 ]); 

% configure and export
xlim([min(tdatetomatlab(fullsample_m.date)) max(tdatetomatlab(fullsample_m.date))]); 
datetick('x','yyyy','keeplimits','keepticks'); 

% legend({'RV'},'Interpreter','latex','Location','North');
legend({'RV $\hat{\sigma}_m$'},'Interpreter','latex','Location','North'); 

set(gcf,'Position',pos); 
set(gcf,'Color',[1 1 1]); 
%
export_fig(gcf,[ base_folder 'longm_sighat.png' ],'-r600'); 

% Now do same for sigsq_both and sigsq_rv in recent sample
close all;

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1, ...
    'XTickLabel',num2str(1990:2:2014), ...
    'XTick',datenum(1990:2:2014,12,31), ...
    'FontName','CMU Serif'); 

box(axes1,'on');
hold(axes1,'on');

% plot sigsq_rv
plot1 = plot(tdatetomatlab(vixsample_d.date),100*sqrt(252*vixsample_d.sigsq_rv), ...
    'Color',0*ones(1,3)); 

% plot sigsq_both
plot1 = plot(tdatetomatlab(vixsample_d.date),100*sqrt(252*vixsample_d.sigsq_both), ...
    'Color',0.6*ones(1,3)); 
% plot1 = plot(tdatetomatlab(vixsample_d.date),vixsample_d.vix*100, ...
%     'Color',0.6*ones(1,3)); 

% configure and export
xlim([min(tdatetomatlab(vixsample_d.date)) max(tdatetomatlab(vixsample_d.date))]); 
datetick('x','yyyy','keeplimits','keepticks'); 

legend({'RV $\hat{\sigma}_d$','VIXF $\hat{\sigma}_d$'},'Interpreter','latex','Location','North'); 

set(gcf,'Position',pos); 
set(gcf,'Color',[1 1 1]); 

%
export_fig(gcf,[ base_folder 'shortd_sighat.png' ],'-r600'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make Figure 3: vrp figure

disp('Making Figure 3: Predicting Returns using the Variance Risk Premium');

make_vrp_figures; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Make OAPP intl vrp table

disp('Making Online Appenix Tables 3 and 4: Country-Specific VRP Regressions');

% Online appendix table 3: Asy SEs
clear params; 
params.simse = false;
params.usehod = false; 
params.data_folder = data_folder; 
[ OAppTable3a, OAppTable3b, OAppTable3c, OAppTable3d ] = make_intlvrp_table(params); 

% Online appendix table 4: Sim SEs
params.simse = true; 
params.nsim = global_num_sims; 
params.usehod = true;
[ OAppTable4a, OAppTable4b, OAppTable4c, OAppTable4d ] = make_intlvrp_table(params); 

% Online appendix summary table
OAppIntlSummary = [ sum(OAppTable3a(2:3:end,3) > -norminv(.025)) sum(OAppTable3a(2:3:end,6) > -norminv(.025)) sum(max(OAppTable3a(2:3:end,:),[],2) > -norminv(.025)); ...
    sum(OAppTable3b(2:3:end,3) > -norminv(.025)) sum(OAppTable3b(2:3:end,6) > -norminv(.025)) sum(max(OAppTable3b(2:3:end,:),[],2) > -norminv(.025)); ...
    sum(OAppTable3c(2:3:end,3) > -norminv(.025)) sum(OAppTable3c(2:3:end,6) > -norminv(.025)) sum(max(OAppTable3c(2:3:end,:),[],2) > -norminv(.025)); ...
    sum(OAppTable3d(2:3:end,3) > -norminv(.025)) sum(OAppTable3d(2:3:end,6) > -norminv(.025)) sum(max(OAppTable3d(2:3:end,:),[],2) > -norminv(.025)); ...
    sum(OAppTable4a(2:3:end,3) > -norminv(.025)) sum(OAppTable4a(2:3:end,6) > -norminv(.025)) sum(max(OAppTable4a(2:3:end,:),[],2) > -norminv(.025)); ...
    sum(OAppTable4b(2:3:end,3) > -norminv(.025)) sum(OAppTable4b(2:3:end,6) > -norminv(.025)) sum(max(OAppTable4b(2:3:end,:),[],2) > -norminv(.025)); ...
    sum(OAppTable4c(2:3:end,3) > -norminv(.025)) sum(OAppTable4c(2:3:end,6) > -norminv(.025)) sum(max(OAppTable4c(2:3:end,:),[],2) > -norminv(.025)); ...
    sum(OAppTable4d(2:3:end,3) > -norminv(.025)) sum(OAppTable4d(2:3:end,6) > -norminv(.025)) sum(max(OAppTable4d(2:3:end,:),[],2) > -norminv(.025)) ];

% write everything to csv 
out_params.numdigits = 2; 
out_params.secondrow = 'tstats'; 
writetable_tj([ base_folder 'OAppTable3a.csv' ],OAppTable3a,1:3:19,2:3:20,out_params); 
writetable_tj([ base_folder 'OAppTable3b.csv' ],OAppTable3b,1:3:19,2:3:20,out_params); 
writetable_tj([ base_folder 'OAppTable3c.csv' ],OAppTable3c,1:3:19,2:3:20,out_params); 
writetable_tj([ base_folder 'OAppTable3d.csv' ],OAppTable3d,1:3:19,2:3:20,out_params); 
writetable_tj([ base_folder 'OAppTable4a.csv' ],OAppTable4a,1:3:19,2:3:20,out_params); 
writetable_tj([ base_folder 'OAppTable4b.csv' ],OAppTable4b,1:3:19,2:3:20,out_params); 
writetable_tj([ base_folder 'OAppTable4c.csv' ],OAppTable4c,1:3:19,2:3:20,out_params); 
writetable_tj([ base_folder 'OAppTable4d.csv' ],OAppTable4d,1:3:19,2:3:20,out_params); 

csvwrite([ base_folder 'OAppIntlSummary.csv' ],OAppIntlSummary); 


