function [ nm_table, nm_table_chisq ] = make_nm_table(novymarx,params)
% function [ nm_table, nm_table_chisq ] = make_nm_table(novymarx,params)
%
%   Estimates and tabulates predictability afforded by ten variables from
%   Novy Marx (2013) using both OLS and WLS. 
%
%       novymarx is a table with: month, sigsq_rv, mktrf, dem, nyc_temp, global_temp,
%       global_temp_ma12, elnino_ma60, sunspots, sunspots_ma125,
%       marssaturn, jupitersaturn, rv_0
%
%       params is a stuct with: nsim = number of simulations to do
%
%       produces Table with all coefficients and p-values (simulated)

% date range for everything
startmonth = 196101; 
endmonth = 201212; % to match Novy Marx

% cut to appropriate dates
novymarx = novymarx( novymarx.month >= startmonth & novymarx.month <= endmonth,:); 

% truevar = whatever you want to use as the true variance for wild bootstrap
truevar = novymarx.rv_0;

% predvar = whatever you want to use for weighting regressions
% need to re-reun the first-stage regression
predvar = novymarx.sigsq_rv; 

% this is the r used throughout
r = novymarx.mktrf; 

% T = number of observations
T = length(truevar); 

params.lhsmultiplier = 100; 

table_ncol = 3; 

% UNIVARIATE

% compile matrix of all xs we'll use, most straight from imported
% novymarx.m
x_mat = [ novymarx.dem novymarx.nyc_temp novymarx.global_temp novymarx.global_temp_ma12 ...
    novymarx.elnino novymarx.elnino_ma60 novymarx.sunspots novymarx.sunspots_ma125 ...
    novymarx.marssaturn novymarx.jupitersaturn ]; 
       
n_pred = size(x_mat,2); 

% now find point estimates using ols and wls-ev
ols_est = NaN(1,n_pred); 
wls_est = NaN(1,n_pred); 
ols_pvalues_asy = NaN(1,n_pred); 
wls_pvalues_asy = NaN(1,n_pred); 

for x_i = 1:n_pred
    [ ols_ab, ols_SE ] = olsgmm( params.lhsmultiplier*r(2:end,1), [ ones(T-1,1) x_mat(1:end-1,x_i) ],params.nlags,1); 
    ols_est(x_i) = ols_ab(2); 
    ols_pvalues_asy(x_i) = 2*normcdf(-abs(ols_ab(2)) / ols_SE(2) ); 
    
    [ wls_ab, wls_SE ] = wlsev( params.lhsmultiplier*r(2:end,1), ... 
                [ ones(T-1,1) x_mat(1:end-1,x_i) ], predvar(1:end-1,1),params.nlags,1);
    wls_est(x_i) = wls_ab(2); 
    wls_pvalues_asy(x_i) = 2*normcdf(-abs(wls_ab(2)) / wls_SE(2) );     
    
    disp(x_i); 
end

% MULTIVARIATE
[ ols_ab_mv,~,~,~,v_ols ] = olsgmm(params.lhsmultiplier*r(2:end,1),[ ones(T-1,1) x_mat(1:end-1,:)],params.nlags,1); 
ols_est_mv = ols_ab_mv(2:end); v_ols = v_ols(2:end,2:end); 
[ wls_ab_mv,~,~,~,v_wls ]  = wlsev(params.lhsmultiplier*r(2:end,1), ... 
        [ones(T-1,1) x_mat(1:end-1,:)],predvar(1:end-1,1),params.nlags,1); 

wls_est_mv = wls_ab_mv(2:end); v_wls = v_wls(2:end,2:end); 

% SIMULATIONS

% compute small sample covariance matrix of predictability coefficients using heteroskedastic bootsraps

% Get simulated returns to use throughout
simr_he = sim_returns(r,predvar,params); 

% Now do regressions with heteroskedastic simr
lhs_sim_mv = params.lhsmultiplier*simr_he(2_mv:end,:); 

ols_ab_mv_sim = [ ones(T-1,1) x_mat(1:end-1,:) ] \ lhs_sim_mv; 
ols_est_mv_sim = ols_ab_mv_sim(2:end,:)'; 

wls_ab_mv_sim  = wlsev(lhs_sim_mv,[ones(T-1,1) x_mat(1:end-1,:)],predvar(1:end-1,1),0,-1); 
wls_est_mv_sim = wls_ab_mv_sim(2:end,:)'; 

% these are matrix of simulated ols_est and wls_est
ols_est_sim = NaN(params.nsim,n_pred); 
wls_est_sim = NaN(params.nsim,n_pred); 

for x_i = 1:n_pred
    lhs_sim_i = params.lhsmultiplier*simr_he(2:end,:); 
    
    ols_ab = [ ones(T-1,1) x_mat(1:end-1,x_i) ] \ lhs_sim_i; 
    ols_est_sim(:,x_i) = ols_ab(2,:)'; 
    wls_ab  = wlsev(lhs_sim_i,[ones(T-1,1) x_mat(1:end-1,x_i)],predvar(1:end-1,1),0,-1); 
    wls_est_sim(:,x_i) = wls_ab(2,:)'; 
    disp(x_i); 
end

% from these, can get individual pvalues
ols_pvalues_sim = NaN(1,n_pred); 
wls_pvalues_sim = NaN(1,n_pred); 
for x_i = 1:n_pred
    ols_pvalues_sim(x_i) = mean(abs(ols_est_sim(:,x_i)) >= abs(ols_est(x_i))); 
    wls_pvalues_sim(x_i) = mean(abs(wls_est_sim(:,x_i)) >= abs(wls_est(x_i))); 
end

% small sample cov matrix
ols_cov_mat = cov(ols_est_mv_sim); 
wls_cov_mat = cov(wls_est_mv_sim); 

% now can compute chi_sq stat for data point estimates
ols_chisq_data = ols_est_mv'*(ols_cov_mat)^-1*ols_est_mv; 
wls_chisq_data = wls_est_mv'*(wls_cov_mat)^-1*wls_est_mv; 

% now can compute pvalues for both using simulated chisq stats
ols_chisq_sim = NaN(params.nsim,1); 
wls_chisq_sim = NaN(params.nsim,1); 
for sim_i = 1:params.nsim
    ols_chisq_sim(sim_i) = ols_est_mv_sim(sim_i,:)*(ols_cov_mat)^-1*ols_est_mv_sim(sim_i,:)'; 
    wls_chisq_sim(sim_i) = wls_est_mv_sim(sim_i,:)*(wls_cov_mat)^-1*wls_est_mv_sim(sim_i,:)'; 
    if(mod(sim_i,1000) == 0)
        disp(sim_i); 
    end
end

ols_chisq_pvalue = mean(ols_chisq_sim > ols_chisq_data); 
wls_chisq_pvalue = mean(wls_chisq_sim > wls_chisq_data); 

% chi2 asymptotic
ols_chisq_asy = ols_est_mv'*(v_ols)^-1*ols_est_mv; 
wls_chisq_asy = wls_est_mv'*(v_wls)^-1*wls_est_mv; 
ols_chisq_pvalue_asy = 1-chi2cdf(ols_chisq_asy,n_pred); 
wls_chisq_pvalue_asy = 1-chi2cdf(wls_chisq_asy,n_pred); 

% now format into a the right shaped table
table_nrows = ceil(n_pred/table_ncol);
nm_table = -99*ones(table_nrows*3,table_ncol*2); 
for row = 1:ceil(n_pred/table_ncol)
    % how many do we have for this row?
    rowstart = table_ncol*(row-1)+1; 
    rowend = min(table_ncol*(row-1)+table_ncol,n_pred); 
    n_x_in_row = rowend-rowstart+1; 
    
    % ols coeff
    nm_table(3*(row-1)+1,1:2:1+2*(n_x_in_row-1)) = ols_est(rowstart:rowend); 
    % ols pvalues
    nm_table(3*(row-1)+2,1:2:1+2*(n_x_in_row-1)) = ols_pvalues_asy(rowstart:rowend); 
    nm_table(3*(row-1)+3,1:2:1+2*(n_x_in_row-1)) = ols_pvalues_sim(rowstart:rowend); 
    % wls coeff
    nm_table(3*(row-1)+1,2:2:2+2*(n_x_in_row-1)) = wls_est(rowstart:rowend); 
    % wls pvalues
    nm_table(3*(row-1)+2,2:2:2+2*(n_x_in_row-1)) = wls_pvalues_asy(rowstart:rowend); 
    nm_table(3*(row-1)+3,2:2:2+2*(n_x_in_row-1)) = wls_pvalues_sim(rowstart:rowend); 
end

nm_table_chisq = [ ols_chisq_asy  wls_chisq_asy ; ...
    ols_chisq_pvalue_asy  wls_chisq_pvalue_asy; ...
    ols_chisq_data wls_chisq_data; ...
    ols_chisq_pvalue wls_chisq_pvalue ];
