function [ols_col, wls_col ] = make_pres_col(pres_data,simr,selector)
% function [ols_col ,wls_col ] = make_pres_col(pres_data,simr,selector)
% pres_data is a table containing: ret, sigsq_rv, rv_0, and dem
% dem is an indicator for whether president is a democrat at end of month m
% selector indicates which rows of sigsq_rv we are using for the regression
% if row i has selector=true, we include observation return from row i+1,
% dem from row i+1, rv_0 from i+1, but sigsq_rv from i
% simr is a struct containing: simr.he, a T x nsim matrix of returns
% simulated from the standard heteroskedastic approach in the paper, and
% simr.fss_he, a T x nsim matrix of returns simulated from the
% heteroskedastic approach with the Ferson et al. slow moving conditional
% mean unrelated to x. 

% T = number of observations
T = height(pres_data); 

% can't use last observation because we don't know next-month variables
selector(end) = false;

ret_inds = find(selector)+1; % predvar = whatever you want to use for weighting regressions
predvar = pres_data.sigsq_rv(selector,1); 

% this is the r used throughout
r = 1200*pres_data.ret(ret_inds,1); 

% this is the dem variable 
dem = pres_data.dem(ret_inds,1); 

% now can cut our T down
T = length(dem); 

% params.lhsmultiplier = 12; 

% UNIVARIATE
[ ols_ab, ols_SE ] = olsgmm( r, [ ones(T,1) dem ],12,1); 
[ wls_ab, wls_SE ] = wlsev( r, [ ones(T,1) dem ],predvar,12,1);

% SIMULATED P VALUES
simr_he = simr.he(ret_inds,:); 
simr_fss_he = simr.fss_he(ret_inds,:); 

ols_ab_sim_he = [ ones(T,1) dem ] \ simr_he; 
wls_ab_sim_he  = wlsev(simr_he,[ones(T,1) dem],predvar,0,-1); 

ols_ab_sim_fss_he = [ ones(T,1) dem ] \ simr_fss_he; 
wls_ab_sim_fss_he  = wlsev(simr_fss_he,[ones(T,1) dem],predvar,0,-1); 

% from these, can get individual pvalues
ols_pvalue_asy = 2*normcdf(-abs(ols_ab(2) / ols_SE(2)));
wls_pvalue_asy = 2*normcdf(-abs(wls_ab(2) / wls_SE(2)));

ols_pvalue_sim_he = mean(abs(ols_ab_sim_he(2,:)) >= abs(ols_ab(2))); 
wls_pvalue_sim_he = mean(abs(wls_ab_sim_he(2,:)) >= abs(wls_ab(2))); 
ols_pvalue_sim_fss_he = mean(abs(ols_ab_sim_fss_he(2,:)) >= abs(ols_ab(2))); 
wls_pvalue_sim_fss_he = mean(abs(wls_ab_sim_fss_he(2,:)) >= abs(wls_ab(2))); 

% now get raw means
dem_mean_ols = sum(ols_ab); 
rep_mean_ols = ols_ab(1); 
dem_mean_wls = sum(wls_ab); 
rep_mean_wls = wls_ab(1); 

ols_col = [ T; dem_mean_ols; rep_mean_ols; ols_ab(2); ols_pvalue_asy; ols_pvalue_sim_he; ols_pvalue_sim_fss_he ]; 
wls_col = [ T; dem_mean_wls; rep_mean_wls; wls_ab(2); wls_pvalue_asy; wls_pvalue_sim_he; wls_pvalue_sim_fss_he ]; 